@@ -25,8 +25,8 @@
 #include <glib.h>
 
 #define GDK_MAJOR_VERSION (3)
-#define GDK_MINOR_VERSION (20)
-#define GDK_MICRO_VERSION (6)
+#define GDK_MINOR_VERSION (22)
+#define GDK_MICRO_VERSION (29)
 
 #ifndef _GDK_EXTERN
 #define _GDK_EXTERN extern
@@ -162,6 +162,16 @@
  */
 #define GDK_VERSION_3_20        (G_ENCODE_VERSION (3, 20))
 
+/**
+ * GDK_VERSION_3_22:
+ *
+ * A macro that evaluates to the 3.22 version of GDK, in a format
+ * that can be used by the C pre-processor.
+ *
+ * Since: 3.20
+ */
+#define GDK_VERSION_3_22        (G_ENCODE_VERSION (3, 22))
+
 /* evaluates to the current stable version; for development cycles,
  * this means the next stable target
  */
@@ -388,5 +398,19 @@
 # define GDK_AVAILABLE_IN_3_20                _GDK_EXTERN
 #endif
 
+#if GDK_VERSION_MIN_REQUIRED >= GDK_VERSION_3_22
+# define GDK_DEPRECATED_IN_3_22               GDK_DEPRECATED
+# define GDK_DEPRECATED_IN_3_22_FOR(f)        GDK_DEPRECATED_FOR(f)
+#else
+# define GDK_DEPRECATED_IN_3_22               _GDK_EXTERN
+# define GDK_DEPRECATED_IN_3_22_FOR(f)        _GDK_EXTERN
+#endif
+
+#if GDK_VERSION_MAX_ALLOWED < GDK_VERSION_3_22
+# define GDK_AVAILABLE_IN_3_22                GDK_UNAVAILABLE(3, 22)
+#else
+# define GDK_AVAILABLE_IN_3_22                _GDK_EXTERN
+#endif
+
 #endif  /* __GDK_VERSION_MACROS_H__ */
 
